const Sequelize = require('Sequelize');

const sequelizeClient = require('../lib/sequelize.js');

const {
  DataTypes,
  Model
} = Sequelize;

class Goods extends Model {}

const attributes = {
  id: {
    type: DataTypes.BIGINT,
    allowNull: false,
    defaultValue: null,
    primaryKey: true,
    autoIncrement: true,
    comment: '货物id',
    field: 'id'
  },
  name: {
    type: DataTypes.STRING(255),
    allowNull: false,
    defaultValue: null,
    primaryKey: false,
    autoIncrement: false,
    comment: '货物名称',
    field: 'name'
  },
  width: {
    type: DataTypes.INTEGER,
    allowNull: false,
    defaultValue: null,
    primaryKey: false,
    autoIncrement: false,
    comment: '宽度(mm)',
    field: 'width'
  },
  height: {
    type: DataTypes.INTEGER,
    allowNull: false,
    defaultValue: null,
    primaryKey: false,
    autoIncrement: false,
    comment: '高度(mm)',
    field: 'height'
  },
  weight: {
    type: DataTypes.INTEGER,
    allowNull: false,
    defaultValue: null,
    primaryKey: false,
    autoIncrement: false,
    comment: '重量(g)',
    field: 'weight'
  },
  img: {
    type: DataTypes.STRING(255),
    allowNull: true,
    defaultValue: null,
    primaryKey: false,
    autoIncrement: false,
    comment: '图片',
    field: 'img'
  },
  wrapImg: {
    type: DataTypes.STRING(255),
    allowNull: true,
    defaultValue: null,
    primaryKey: false,
    autoIncrement: false,
    comment: '带包装图片',
    field: 'wrap_img'
  },
  supplier: {
    type: DataTypes.STRING(64),
    allowNull: false,
    defaultValue: null,
    primaryKey: false,
    autoIncrement: false,
    comment: '供应商',
    field: 'supplier'
  },
  type: {
    type: DataTypes.STRING(32),
    allowNull: true,
    defaultValue: null,
    primaryKey: false,
    autoIncrement: false,
    comment: '类型：成品、辅材',
    field: 'type'
  },
  warehouseId: {
    type: DataTypes.BIGINT,
    allowNull: true,
    defaultValue: null,
    primaryKey: false,
    autoIncrement: false,
    comment: '所在仓库id',
    field: 'warehouse_id'
  },
  warehousePositionId: {
    type: DataTypes.BIGINT,
    allowNull: true,
    defaultValue: null,
    primaryKey: false,
    autoIncrement: false,
    comment: '所在库位id',
    field: 'warehouse_position_id'
  },
  status: {
    type: DataTypes.STRING(64),
    allowNull: false,
    defaultValue: null,
    primaryKey: false,
    autoIncrement: false,
    comment: '货物状态：已入库、已出库',
    field: 'status'
  }
};
const options = {
  modelName: 'goods',
  sequelize: sequelizeClient,
  indexes: [],
  freezeTableName: true
};
Goods.init(attributes, options);
module.exports = Goods;